"use strict";

exports.__esModule = true;
exports.default = void 0;

var _webpack = require("webpack");

var _path = require("path");

var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));

var _webpackManifestPlugin = _interopRequireDefault(require("webpack-manifest-plugin"));

var _uglifyjsWebpackPlugin = _interopRequireDefault(require("uglifyjs-webpack-plugin"));

var _swPrecacheWebpackPlugin = _interopRequireDefault(require("sw-precache-webpack-plugin"));

var _babelrc = _interopRequireDefault(require("./babelrc"));

var _utils = require("../utils");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

const useBuiltinConfig = !(0, _utils.hasFile)('.babelrc');

const getUserBabelConfig = () => {
  const babelConfig = require((0, _utils.fromRoot)('.babelrc'));

  if (typeof babelConfig === 'function') {
    return babelConfig();
  }

  return babelConfig;
};

const babelConfig = useBuiltinConfig ? (0, _babelrc.default)() : getUserBabelConfig();
const entry = (0, _utils.hasFile)('src', 'index.tsx') ? (0, _utils.fromRoot)((0, _path.join)('src', 'index.tsx')) : (0, _utils.fromRoot)((0, _path.join)('src', 'index.js'));
const env = process.env.BABEL_ENV || process.env.NODE_ENV;
const isEnvDevelopment = env === 'development';
const isEnvProduction = env === 'production';
const isEnvTest = env === 'test';
const shouldUseSourceMap = process.env.GENERATE_SOURCEMAP !== 'false';

if (!env || !isEnvDevelopment && !isEnvProduction && !isEnvTest) {
  throw new Error( // eslint-disable-next-line prefer-template
  'Using `gd-scripts` requires that you specify `NODE_ENV` or ' + '`BABEL_ENV` environment variables. Valid values are "development", ' + '"test", and "production". Instead, received: ' + JSON.stringify(env) + '.');
}

const publicPath = '/';
const config = {
  mode: 'production',
  // Don't attempt to continue if there are any errors.
  bail: true,
  devtool: shouldUseSourceMap ? 'source-map' : false,
  entry,
  output: {
    // The dist folder.
    path: (0, _utils.fromRoot)('dist'),
    // Generated JS file names (with nested folders).
    // There will be one main bundle, and one file per asynchronous chunk.
    // We don't currently advertise code splitting but Webpack supports it.
    filename: 'static/js/[name].[chunkhash:8].js',
    chunkFilename: 'static/js/[name].[chunkhash:8].chunk.js',
    // We inferred the "public path" (such as / or /my-project) from homepage.
    publicPath,
    // Point sourcemap entries to original disk location (format as URL on Windows)
    devtoolModuleFilenameTemplate: info => (0, _path.resolve)((0, _utils.fromRoot)('src'), info.absoluteResourcePath).replace(/\\/g, '/')
  },
  optimization: {
    minimizer: [new _uglifyjsWebpackPlugin.default({
      uglifyOptions: {
        parse: {
          // we want uglify-js to parse ecma 8 code. However, we don't want it
          // to apply any minfication steps that turns valid ecma 5 code
          // into invalid ecma 5 code. This is why the 'compress' and 'output'
          // sections only apply transformations that are ecma 5 safe
          // https://github.com/facebook/create-react-app/pull/4234
          ecma: 8
        },
        compress: {
          ecma: 5,
          warnings: false,
          // Disabled because of an issue with Uglify breaking seemingly valid code:
          // https://github.com/facebook/create-react-app/issues/2376
          // Pending further investigation:
          // https://github.com/mishoo/UglifyJS2/issues/2011
          comparisons: false
        },
        mangle: {
          safari10: true
        },
        output: {
          ecma: 5,
          comments: false,
          // Turned on because emoji and regex is not minified properly using default
          // https://github.com/facebook/create-react-app/issues/2488
          // eslint-disable-next-line camelcase
          ascii_only: true
        }
      },
      // Use multi-process parallel running to improve the build speed
      // Default number of concurrent runs: os.cpus().length - 1
      parallel: true,
      // Enable file caching
      cache: true,
      sourceMap: shouldUseSourceMap
    })],
    // Automatically split vendor and commons
    // https://twitter.com/wSokra/status/969633336732905474
    // https://medium.com/webpack/webpack-4-code-splitting-chunk-graph-and-the-splitchunks-optimization-be739a861366
    splitChunks: {
      chunks: 'all',
      name: 'vendors'
    },
    // Keep the runtime chunk seperated to enable long term caching
    // https://twitter.com/wSokra/status/969679223278505985
    runtimeChunk: true
  },
  resolve: {
    extensions: ['.web.js', '.mjs', '.js', '.json', '.web.jsx', '.ts', '.tsx']
  },
  module: {
    // Makes missing exports an error instead of warning
    strictExportPresence: true,
    rules: [// Disable require.ensure as it's not a standard language feature.
    {
      parser: {
        requireEnsure: false
      }
    }, {
      // "oneOf" will traverse all following loaders until one will
      // match the requirements. When no loader matches it will fall
      // back to the "file" loader at the end of the loader list.
      oneOf: [// "url" loader works like "file" loader except that it embeds assets
      // smaller than specified limit in bytes as data URLs to avoid requests.
      // A missing `test` is equivalent to a match.
      {
        test: [/\.bmp$/, /\.gif$/, /\.jpe?g$/, /\.png$/],
        loader: require.resolve('url-loader'),
        options: {
          limit: 10000,
          name: 'static/media/[name].[hash:8].[ext]'
        }
      }, {
        test: /\.((j|t)sx?|mjs)$/,
        include: (0, _utils.fromRoot)('src'),
        exclude: [/[/\\\\]node_modules[/\\\\]/],
        use: [// This loader parallelizes code compilation, it is optional but
        // improves compile time on larger projects
        {
          loader: require.resolve('thread-loader'),
          options: {
            poolTimeout: Infinity // keep workers alive for more effective watch mode

          }
        }, {
          loader: require.resolve('babel-loader'),
          options: _extends({}, babelConfig, {
            cacheDirectory: true,
            highlightCode: true
          })
        }]
      }, // Process any JS outside of the app with Babel.
      // Unlike the application JS, we only compile the standard ES features.
      {
        test: /\.js$/,
        use: [{
          loader: require.resolve('babel-loader'),
          options: {
            babelrc: false,
            compact: false,
            presets: [isEnvTest && [// ES features necessary for user's Node version
            require('@babel/preset-env').default, {
              targets: {
                node: 'current'
              },
              // Do not transform modules to CJS
              modules: false
            }], (isEnvProduction || isEnvDevelopment) && [// Latest stable ECMAScript features
            require('@babel/preset-env').default, {
              // Do not transform modules to CJS
              modules: false
            }]].filter(Boolean),
            cacheDirectory: true,
            highlightCode: true
          }
        }]
      }, // "file" loader makes sure those assets get served by WebpackDevServer.
      // When you `import` an asset, you get its (virtual) filename.
      // In production, they would get copied to the `dist` folder.
      // This loader doesn't use a "test" so it will catch all modules
      // that fall through the other loaders.
      {
        // Exclude `js` files to keep "css" loader working as it injects
        // its runtime that would otherwise be processed through "file" loader.
        // Also exclude `html` and `json` extensions so they get processed
        // by webpacks internal loaders.
        exclude: [/\.((j|t)sx?|mjs)$/, /\.html$/, /\.json$/],
        loader: require.resolve('file-loader'),
        options: {
          name: 'static/media/[name].[hash:8].[ext]'
        }
      }]
    }]
  },
  plugins: [// Generates an `index.html` file with the <script> injected.
  new _htmlWebpackPlugin.default({
    inject: true,
    template: (0, _utils.fromRoot)((0, _path.join)('public', 'index.html')),
    minify: {
      removeComments: true,
      collapseWhitespace: true,
      removeRedundantAttributes: true,
      useShortDoctype: true,
      removeEmptyAttributes: true,
      removeStyleLinkTypeAttributes: true,
      keepClosingSlash: true,
      minifyJS: true,
      minifyCSS: true,
      minifyURLs: true
    }
  }), new _webpack.DefinePlugin({
    'process.env': {
      NODE_ENV: JSON.stringify(env)
    }
  }), // Generate a manifest file which contains a mapping of all asset filenames
  // to their corresponding output file so that tools can pick it up without
  // having to parse `index.html`.
  new _webpackManifestPlugin.default({
    fileName: 'asset-manifest.json',
    publicPath
  }), new _swPrecacheWebpackPlugin.default({
    // By default, a cache-busting query parameter is appended to requests
    // used to populate the caches, to ensure the responses are fresh.
    // If a URL is already hashed by Webpack, then there is no concern
    // about it being stale, and the cache-busting can be skipped.
    dontCacheBustUrlsMatching: /\.\w{8}\./,
    filename: 'service-worker.js',

    logger(message) {
      if (message.indexOf('Total precache size is') === 0) {
        // This message occurs for every build and is a bit too noisy.
        return;
      }

      if (message.indexOf('Skipping static resource') === 0) {
        // This message obscures real errors so we ignore it.
        // https://github.com/facebook/create-react-app/issues/2612
        return;
      }

      console.log(message);
    },

    minify: true,
    // Don't precache sourcemaps (they're large) and build asset manifest:
    staticFileGlobsIgnorePatterns: [/\.map$/, /asset-manifest\.json$/] // `navigateFallback` and `navigateFallbackWhitelist` are disabled by default; see
    // https://github.com/facebook/create-react-app/blob/master/packages/react-scripts/template/README.md#service-worker-considerations
    // navigateFallback: publicUrl + '/index.html',
    // navigateFallbackWhitelist: [/^(?!\/__).*/],

  })],
  // Some libraries import Node modules but don't use them in the browser.
  // Tell Webpack to provide empty mocks for them so importing them works.
  node: {
    dgram: 'empty',
    fs: 'empty',
    net: 'empty',
    tls: 'empty',
    // eslint-disable-next-line camelcase
    child_process: 'empty'
  }
};
var _default = config;
exports.default = _default;
//# sourceMappingURL=webpack.config.prod.js.map